@@ -159,15 +159,24 @@ sub pod2man {
 }
 
 sub pod2html {
-    my ($o, $pod, $section) = @_;
-    my $stem = $pod;
-    $stem =~ s/\.[^.]+$//;
-    $o->clean("$stem.html", "pod2html-dircache", "pod2html-itemcache");
-    new Maker::Unit("$stem.html", sub {
-	if (newer("$stem.html", $pod)) {
-	    $o->x("pod2html $pod > $stem.html");
-	}
-    });
+    my $o = shift @_;
+    my @r;
+    for my $pod (@_) {
+	my $stem = $pod;
+	$stem =~ s/\.[^.]+$//;
+	$o->clean("$stem.html");
+	push(@r, new Maker::Unit("$stem.html", sub {
+	    if (newer("$stem.html", $pod)) {
+		$o->x("pod2html $pod > $stem.html");
+	    }
+	}));
+    }
+    $o->spotless("pod2html-dircache", "pod2html-itemcache");
+    if (@r == 1) {
+	@r;
+    } else {
+	new Maker::Phase(@r);
+    }
 }
 
 sub _make_install_dirs {
@@ -202,8 +211,12 @@ sub _populate_install {
 		    }
 		} else {
 		    if (!$real) {
+			my $base = $f;
+			$base =~ s|^.*/||;
 			if (-e $f and newer("$blib/$f", $f)) {
 			    $o->x('cp', $f, "$blib/$f");
+			} elsif (-e $base and newer("$blib/$f", $base)) {
+			    $o->x('cp', $base, "$blib/$f");
 			}
 		    } else {
 			if (-e "$blib/$f") {
